#
# spec file for package menu-cache
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           menu-cache
Version:        1.0.0
Release:        4.3
Summary:        A tool speed up menus
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/GUI/LXDE
Url:            http://www.lxde.org
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gtk-doc
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig(libfm-extra)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libmenu-cache is a library creating and utilizing caches to speed up
the manipulation for freedesktop.org defined application menus.
It can be used as a replacement of libgnome-menu of gnome-menus.

%package devel
Summary:        Menu-cache Headers
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libmenu-cache3 = %{version}
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(libfm-extra)

%description devel
%{name} development files

%package -n libmenu-cache3
Summary:        Menu-cache libraries
Group:          System/Libraries

%description  -n libmenu-cache3
%{name} libraries for development

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}

%post -n libmenu-cache3 -p /sbin/ldconfig

%postun -n libmenu-cache3 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README AUTHORS COPYING NEWS
%{_libexecdir}/%{name}

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_libdir}/libmenu-cache.so
%{_libdir}/pkgconfig/libmenu-cache.pc

%files -n libmenu-cache3
%defattr(-,root,root)
%{_libdir}/libmenu-cache.so.3
%{_libdir}/libmenu-cache.so.3.1.0

%changelog
* Mon Sep 29 2014 trcs@gmx.com
- update to pre-release version 1.0.0
  * A little code optimization
  * Fix compilation warning
  * Fix DISTCLEANFILES in docs - generated files should be cleaned
  * Add Log Domain "Menu-Cache" for better library logging
    messages
  * Fixed bug when cache was not updated while it should
  * Added new cache file format generation support with changes:
  - invisible directories (NoDisplay=true or empty) can be put
    into the cache too but with flag (not displayed) set;
  - content of TryExec field is added to contents of cache file;
  - the working dir to execute application is added to cache
    file;
  - list of categories is added to contents of cache file;
  - list of keywords is added to contents of cache file.
  * Fixed crash in menu_cache_item_get_file_dirname() for a
    non-existent file (might happen for directories without
    .directory file).
  * Made menu_cache_app_get_working_dir() actually work.
  * Made menu_cache_lookup() faster (do not load cache immediately
    but on idle instead).
  * Eliminated secondary cache reload in menu_cache_lookup_sync()
  - server response in such case will be ahead of idle reload
    (since main thread is in wait ATM) and therefore idle call
    will be supressed.
  * Added new API menu_cache_app_get_categories() to get list of
    categories for the application.
  * Added new APIs for applications:
    menu_cache_list_all_for_category() and
    menu_cache_list_all_for_keyword() that return list of
    applications matching criteria.
  * Fixed problem if some string in the desktop entry file
    contained a new line character. That broke cache file format,
    now it's replaced with a "\n" string and converted back into
    new line in the library.
- applied spec-cleaner
* Sat Sep  6 2014 trcs@gmx.com
- New upstream release 0.7.0
  * autogen.sh: do not do configure until $DOCONGIGURE is set to
    non-empty
  * menu-cache-gen: don't fail on improper menu sctructure when
    verbose=0
  * Be more verbose on file loading failures. May be better not
    fail at all?
  * menu-cache-gen: don't fail if <MergeFile> file isn't found,
    just skip it
  * Fix menu-cached crash after menu-cache-gen failure
  * Handles menu-cached failures more gracefully in libmenu-cache
  * Add a parameter for menu-cached to specify socket path
  * Fix unrequested empty directories in default mode
  * Fix support for <Move> tag - it should move not into <New> but
  to <New> instead
  * debian: add libfm-dev into build dependencies
  * debian: dh-autoreconf was missing in debian/control file
  * Fix './configure --help' formatting and update NEWS file
  * Update output of 'menu-cache-gen -h' command
  * menu-cache-gen: implement inline_alias attribute support
  * Take show_empty attribute into consideration in _stage2()
  * Add option --verbose for menu-cache-gen (quiet by default, max
    3 verbosity level)
  * Support NoDisplay in <Directory> files (menu-cache-gen) to
    hide folder
  * Update AUTHORS and README files
  * Fixing memory problems in menu-cache-gen
  * Pass LegacyDir prefix to menu-cache-gen composer using XML
    comment
  * menu-cache-gen: add support for <KDELegacyDirs> tag
  * Implement support for 'inline' attribute of <Menuname> tag in
    menu-cache-gen
  * Fix check for duplicates in menu-cache-gen merging
  * Add support into menu-cache-gen for <LegacyDir> tag
  * Fix few parsing issues in ragards to desktop menu
    specifications
  * libmenu-cache: send languages list to menu-cache-gen instead
    of single lang code
  * Support for <Move> tag in menu-cache-gen
  * Check for mandatory <Name> for <Menu> tags
  * First draft on menu-cache-gen, it works now it seems
  * Add main() function to menu-cache-gen
  * Make save_menu_cache() safe - rename temp file into it if no
    errors only
  * The 'menu-cache-gen': new implementation based on FmXmlFile
    parser
* Tue Aug 26 2014 trcs@gmx.com
- new upstream version 0.6.1
  * Fixed invalid memory access after cache reload.
  * A little cleanup of dist tarball: removed unused files
    menu-cache.h and libmenu-cache-uninstalled.pc.in.
* Sun Aug  3 2014 trcs@gmx.com
- new upstream version 0.6.0
  * Fixed few GLIB compatibility issues.
  * Changed default tarball format to XZ instead of GZIP.
  * Fixed build without --enable-gtk-doc.
  * Fixed crash on access root_dir with empty cache (no menu).
  * Allowed menu_cache_get_desktop_env_flag() accept colon-separated list in accordance to
    freedesktop.org specification for the environment variable XDG_CURRENT_DESKTOP.
  * The case if user deleted cache file is handled: it will be regenerated.
* Fri Jul  4 2014 andrea@opensuse.org
- Spec file clean up, we should not provide and obsolete libmenu-cache2
* Sun Jan  5 2014 trcs@eresmas.com
- minor changes
  * Fixed build on systems where MAXSYMLINKS isn't defined.
  * Fixed menu-cached crash in some rare cases.
- Complete changelog in http://blog.lxde.org/?p=1057
* Wed Sep  4 2013 i@marguerite.su
- update version 0.5.0
  * Added a possibility to include NoDisplay files into cache file
  * New macro MENU_CACHE_CHECK_VERSION()
  * Added new APIs: menu_cache_find_item_by_id, menu_cache_find_child_by_id,
    menu_cache_find_child_by_name.
  * bugfixes
* Wed Dec 19 2012 andrea@opensuse.org
- new upstream version 0.4.1
  * The libmenu-cache is made thread-safe. Thread-unsafe APIs are marked
    as deprecated now and should be never used in any multithreaded application.
  * Added creation of HTML developers documentation. It is triggered
    by configure script option –enable-gtk-doc.
  * The libmenu-cache is made more responsible by moving some time-critical
    operations into thread. Also it preloads saved cache file if it exists
    so it is available near instantly after menu_cache_lookup().
    Caller still will get updates by adding notifier to the cache.
  * Added automatic shutdown of menu-cached server after some inactivity
    timeout (i.e. all clients were unregistered).
  * Fixed few memory problems (referencing errors and memory leaks).
  * Fix for bug #3501347: use g_get_tmp_dir() instead of hardcoded “/tmp”.
  * The libmenu-cache ABI bumped to 2.
* Tue May 29 2012 andrea@opensuse.org
- New upstream version 0.3.3
  * bug fix release
- added URL tag in spec file
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Mon Aug  2 2010 andrea@opensuse.org
- fixed libmenu-cache1 RPM Group
* Mon Jun  7 2010 andrea@opensuse.org
- changed RPM Group to System/GUI/LXDE on main package
* Sat Feb 27 2010 andrea@opensuse.org
- new upstream version 0.3.2
  * several bug fix
  * API changes
  * soname changed
* Wed Feb 17 2010 andrea@opensuse.org
- new upstream version 0.3.1
  * important bug fix
  * menu-generation is now client side
  * speed up and lower memory usage
* Fri Dec 11 2009 andrea@opensuse.org
- clean up spec file
- used chrpath to purge from rpath linking
- bzipped source code
* Sun Nov  8 2009 andrea@opensuse.org
- new upstream version 0.2.6
- Security fix
* Sat May 23 2009 andrea@opensuse.org
- new package
